@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-from datetime import datetime
+import datetime
 
 from aenum import Enum, unique
 from related import (
@@ -14,16 +14,14 @@ from related import (
 
 from ._subject import Subject
 from ._teacher import Teacher
-from ._utils import sort_and_filter_date
+from ._utils import sort_and_filter_dates
 
 
 @unique
 class ExamType(Enum):
-    """
-    Exam type
+    """Exam type
 
-    Todo:
-        Add test enum
+    .. todo:: Add test enum
     """
 
     EXAM = 1
@@ -33,16 +31,14 @@ class ExamType(Enum):
 
 @immutable
 class Exam:
-    """
-    Exam, test, short test or class test
+    """Exam, test, short test or class test
 
-    Attributes:
-        id (:class:`int`): Exam ID
-        type (:class:`vulcan._exam.ExamType`): Exam type
-        description (:class:`str`): Exam description
-        date (:class:`datetime.date`): Exam date
-        teacher (:class:`vulcan._teacher.Teacher`): Teacher, who added the exam
-        subject (:class:`vulcan._subject.Subject`): Subject, from which is the exam
+    :var int ~.id: Exam ID
+    :var `~vulcan._exam.ExamType` ~.type: Exam type
+    :var str ~.description: Exam description
+    :var `datetime.date` ~.date: Exam date
+    :var `~vulcan._teacher.Teacher` ~.teacher: Teacher, who added the exam
+    :var `~vulcan._subject.Subject` ~.subject: Subject, from which is the exam
     """
 
     id = IntegerField(key="Id")
@@ -54,16 +50,20 @@ class Exam:
     subject = ChildField(Subject, required=False)
 
     @classmethod
-    def get(cls, api, date):
-        if not date:
-            date = datetime.now()
-        date_str = date.strftime("%Y-%m-%d")
+    def get(cls, api, date_from, date_to):
+        if not date_from:
+            date_from = datetime.date.today()
+        if not date_to:
+            date_to = date_from
 
-        data = {"DataPoczatkowa": date_str, "DataKoncowa": date_str}
+        data = {
+            "DataPoczatkowa": date_from.strftime("%Y-%m-%d"),
+            "DataKoncowa": date_to.strftime("%Y-%m-%d"),
+        }
 
         j = api.post("Uczen/Sprawdziany", json=data)
 
-        exams = sort_and_filter_date(j.get("Data", []), date_str)
+        exams = sort_and_filter_dates(j.get("Data", []), date_from, date_to)
 
         for exam in exams:
             exam["teacher"] = api.dict.get_teacher_json(exam["IdPracownik"])
